@@ -3,6 +3,7 @@ from __future__ import print_function
 
 import argparse
 from sys import stderr, stdout, stdin, exit
+import os.path
 import logging
 import codecs
 
@@ -13,7 +14,7 @@ from IPython.config import Config
 from IPython.nbconvert.exporters.html import HTMLExporter
 
 def main():
-    log_format = '%(asctime)s %(message)s'
+    log_format = '%(asctime)s %(levelname)s: %(message)s'
     log_datefmt = '%m/%d/%Y %I:%M:%S %p'
 
     parser = argparse.ArgumentParser()
@@ -39,6 +40,8 @@ def main():
             help='print notebook to stdout (or use - as output_file')
     parser.add_argument('--stdin', action='store_true',
             help='read notebook from stdin (or use - as input_file)')
+    parser.add_argument('--no-chdir', action='store_true',
+            help="do not change directory to notebook's at kernel startup")
     args = parser.parse_args()
 
 
@@ -51,7 +54,9 @@ def main():
             args.output_file = args.input_file
 
     if not args.quiet:
-        logging.basicConfig(level=logging.DEBUG, format=log_format, datefmt=log_datefmt)
+        logging.basicConfig(level=logging.INFO, format=log_format, datefmt=log_datefmt)
+
+    working_dir = None
 
     if args.input_file == '-' or args.stdin:  # force stdin
         payload = stdin
@@ -62,10 +67,14 @@ def main():
         payload = stdin
     else:  # must have specified normal input_file
         payload = open(args.input_file)
+        working_dir = os.path.dirname(args.input_file)
+
+    if args.no_chdir:
+        working_dir = None
 
     logging.info('Reading notebook %s', payload.name)
     nb = read(payload, 'json')
-    nb_runner = NotebookRunner(nb, args.pylab, args.matplotlib)
+    nb_runner = NotebookRunner(nb, args.pylab, args.matplotlib, working_dir)
 
     exit_status = 0
     try:
@@ -79,6 +88,7 @@ def main():
 
     if args.stdout or args.output_file == '-':
         write(nb_runner.nb, stdout, 'json')
+        print()
 
     if args.html is not False:
         if args.html is None:
